==> App-Music-ChordPro-6.010.tar.gz: App-Music-ChordPro-6.010/README.md <==
# [ChordPro](https://www.chordpro.org)
*A lyrics and chords formatting program*

![Version](https://img.shields.io/github/v/release/ChordPro/chordpro)
![GitHub issues](https://img.shields.io/github/issues/chordpro/chordpro)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
[![Built by
musicians](https://img.shields.io/badge/built%20by-musicians%20𝄞-d15d27.svg?&labelColor=e36d25)](https://forthebadge.com)
![Language Perl](https://img.shields.io/badge/Language-Perl-blue)
[![User Forum](https://img.shields.io/badge/forum-groups.io%2Fg%2FChordPro-8fff00)](https://groups.io/g/ChordPro)

ChordPro generates professional-looking sheet music from a text file
containing the lyrics of one or many songs with chord information.
Check <https://chordpro.org/chordpro/ChordPro-Installation.html> for installation instructions
and execute `chordpro --help` for an overview about the available options.

## Support
For general discussion, please see [the user group](https://groups.io/g/ChordPro/topics).

Bugs and feature requests go to [the GitHub issue tracker](https://github.com/ChordPro/chordpro/issues).

## Development Status
This program implements ChordPro language version 6.
It is the successor of [*Chord* and *Chord*<sub><i>ii</i></sub>](https://chordpro.org/chordpro/ChordPro-History.md)
with additional features such as native PDF generation,
Unicode input and fully customizable layout, fonts and sizes.

Prominent features of ChordPro 6 are
Pango style text markup, annotations,
and a more powerful way of assigning typefaces to layout items.

For up-to-date information, see [The ChordPro implementation](https://chordpro.org/chordpro/ChordPro-Reference-Implementation.html).

## License

Copyright © 2010,2018,2023 The ChordPro Team

This program is free software. You can redistribute it and/or modify it under the terms of the Artistic License 2.0.

==> App-Music-ChordPro-6.050.6.tar.gz: App-Music-ChordPro-6.050.6/README.md <==
# [ChordPro](https://www.chordpro.org)
*A lyrics and chords formatting program*

![Version](https://img.shields.io/github/v/release/ChordPro/chordpro)
![GitHub issues](https://img.shields.io/github/issues/chordpro/chordpro)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
[![Built by
musicians](https://img.shields.io/badge/built%20by-musicians%20𝄞-d15d27.svg?&labelColor=e36d25)](https://forthebadge.com)
![Language Perl](https://img.shields.io/badge/Language-Perl-blue)
[![User Forum](https://img.shields.io/badge/forum-groups.io%2Fg%2FChordPro-8fff00)](https://groups.io/g/ChordPro)

ChordPro generates professional-looking sheet music from a text file
containing the lyrics of one or many songs with chord information.
Check <https://chordpro.org/chordpro/chordpro-installation/> for installation instructions
and execute `chordpro --help` for an overview about the available options.

## Support
For general discussion, please see [the user group](https://groups.io/g/ChordPro/topics).

Bugs and feature requests go to [the GitHub issue tracker](https://github.com/ChordPro/chordpro/issues).

## Development Status
This program implements ChordPro language version 6.
It is the successor of [*Chord* and *Chord*<sub><i>ii</i></sub>](https://chordpro.org/chordpro/chordpro-history/)
with additional features such as native PDF generation,
Unicode input and fully customizable layout, fonts and sizes.

Prominent features of ChordPro 6 are
Pango style text markup, annotations,
and a more powerful way of assigning typefaces to layout items.

For up-to-date information, see [The ChordPro implementation](https://chordpro.org/chordpro/chordpro-reference-implementation/).

## License

Copyright © 2010,2018,2023 The ChordPro Team

This program is free software. You can redistribute it and/or modify it under the terms of the Artistic License 2.0.
